!SURFEX_LIC Copyright 1994-2014 Meteo-France 
!SURFEX_LIC This is part of the SURFEX software governed by the CeCILL-C  licence
!SURFEX_LIC version 1. See LICENSE, CeCILL-C_V1-en.txt and CeCILL-C_V1-fr.txt
!SURFEX_LIC for details. version 1.
!     ################
      MODULE MODD_BLD_DESCRIPTION
!     ################
!
!!****  *MODD_BLD_DESCRIPTION - declaration of surface parameters for typical
!                               buildings
!!
!!    PURPOSE
!!    -------
!     Declaration of surface parameters
!
!!
!!**  IMPLICIT ARGUMENTS
!!    ------------------
!!      None 
!!
!!    REFERENCE
!!    ---------
!!
!!    AUTHOR
!!    ------
!!	G. Pigeon   *Meteo France*
!!
!!    MODIFICATIONS
!!    -------------
!!      Original       08/2011
!
!*       0.   DECLARATIONS
!             ------------
!
USE YOMHOOK   ,ONLY : LHOOK,   DR_HOOK
USE PARKIND1  ,ONLY : JPRB
!
IMPLICIT NONE

TYPE BLD_DESC_t
!
! Number of layers
!
  INTEGER                       :: NDESC_BLD          ! number of types of buildings
  INTEGER                       :: NDESC_AGE          ! number of building's construction dates ranges
  INTEGER                       :: NDESC_CODE         ! number of codes for buildings (merges type & age)
  INTEGER                       :: NDESC_USE          ! number of types of building's uses
  INTEGER                       :: NDESC_ROOF_LAYER   ! number of layers in roofs
  INTEGER                       :: NDESC_ROAD_LAYER   ! number of layers in roads
  INTEGER                       :: NDESC_WALL_LAYER   ! number of layers in walls
  INTEGER                       :: NDESC_FLOOR_LAYER  ! number of layers in floor
  INTEGER, POINTER, DIMENSION(:):: NDESC_BLD_LIST     ! list of the types for buildings
  INTEGER, POINTER, DIMENSION(:):: NDESC_AGE_DATE     ! list of the contruction dates for buildings
  INTEGER, POINTER, DIMENSION(:):: NDESC_CODE_LIST    ! list of the codes for buildings
  INTEGER, POINTER, DIMENSION(:):: NDESC_AGE_LIST     ! list of the contruction dates' codes
  INTEGER, POINTER, DIMENSION(:):: NDESC_USE_LIST     ! list of the codes for building's uses
  !
  REAL, POINTER, DIMENSION(:)   :: XDESC_ALB_ROOF     ! Roof albedo
  REAL, POINTER, DIMENSION(:)   :: XDESC_ALB_ROAD     ! Road albedo
  REAL, POINTER, DIMENSION(:)   :: XDESC_ALB_WALL     ! Wall albedo
  REAL, POINTER, DIMENSION(:)   :: XDESC_EMIS_ROOF    ! Roof emissivity
  REAL, POINTER, DIMENSION(:)   :: XDESC_EMIS_ROAD    ! Road emissivity
  REAL, POINTER, DIMENSION(:)   :: XDESC_EMIS_WALL    ! Wall emissivity
  REAL, POINTER, DIMENSION(:)   :: XDESC_TCOOL_TARGET ! cooling setpoint of indoor air
  REAL, POINTER, DIMENSION(:)   :: XDESC_THEAT_TARGET ! heating setpoint of indoor air
  REAL, POINTER, DIMENSION(:)   :: XDESC_F_WASTE_CAN  ! fraction of waste heat into the canyon
  REAL, POINTER, DIMENSION(:)   :: XDESC_EFF_HEAT     ! efficiency of the heating system
  REAL, POINTER, DIMENSION(:,:) :: XDESC_HC_FLOOR     ! heat capacity of floor layers [J m-3 K-1]
  REAL, POINTER, DIMENSION(:,:) :: XDESC_TC_FLOOR     ! thermal conductivity of floor layers [W m-1 K-1]
  REAL, POINTER, DIMENSION(:,:) :: XDESC_D_FLOOR      ! thickness of floor layers [m]
  REAL, POINTER, DIMENSION(:,:) :: XDESC_HC_ROOF      ! heat capacity of roof layers [J m-3 K-1]
  REAL, POINTER, DIMENSION(:,:) :: XDESC_TC_ROOF      ! thermal conductivity of roof layers [W m-1 K-1]
  REAL, POINTER, DIMENSION(:,:) :: XDESC_D_ROOF       ! thickness of roof layers [m]
  REAL, POINTER, DIMENSION(:,:) :: XDESC_HC_ROAD      ! heat capacity of road layers [J m-3 K-1]
  REAL, POINTER, DIMENSION(:,:) :: XDESC_TC_ROAD      ! thermal conductivity of road layers [W m-1 K-1]
  REAL, POINTER, DIMENSION(:,:) :: XDESC_D_ROAD       ! thickness of road layers [m]
  REAL, POINTER, DIMENSION(:,:) :: XDESC_HC_WALL      ! heat capacity of wall layers [J m-3 K-1]
  REAL, POINTER, DIMENSION(:,:) :: XDESC_TC_WALL      ! thermal conductivity of wall layers [W m-1 K-1]
  REAL, POINTER, DIMENSION(:,:) :: XDESC_D_WALL       ! thickness of wall layers [m]
  REAL, POINTER, DIMENSION(:)   :: XDESC_QIN          ! internal heat gains [W m-2(floor)]
  REAL, POINTER, DIMENSION(:)   :: XDESC_QIN_FRAD     ! radiant fraction of internal heat gains
  REAL, POINTER, DIMENSION(:)   :: XDESC_SHGC         ! solar transmitance of windows
  REAL, POINTER, DIMENSION(:)   :: XDESC_U_WIN        ! glazing thermal resistance [K m W-2]
  REAL, POINTER, DIMENSION(:)   :: XDESC_GR           ! glazing ratio
  REAL, POINTER, DIMENSION(:)   :: XDESC_SHGC_SH      ! solar transmitance of windows + shading
  REAL, POINTER, DIMENSION(:)   :: XDESC_FLOOR_HEIGHT ! building floor height [m]
  REAL, POINTER, DIMENSION(:)   :: XDESC_INF          ! infiltration/ventilation flow rate [AC/H]
!
  REAL, POINTER, DIMENSION(:)   :: XDESC_F_WATER_COND ! fraction of evaporation for condensers
  REAL, POINTER, DIMENSION(:)   :: XDESC_SHADE        ! Flag to activate shading devices 0->inactivated , 1->activated
  REAL, POINTER, DIMENSION(:)   :: XDESC_NATVENT      ! Flag to describe bld surventilation solution 0-> NONE ; 1 -> MANU ; 2-> AUTO
  REAL, POINTER, DIMENSION(:)   :: XDESC_QIN_FLAT     ! Latent franction of internal heat gains
  REAL, POINTER, DIMENSION(:)   :: XDESC_HR_TARGET    ! Relative humidity setpoint
  REAL, POINTER, DIMENSION(:)   :: XDESC_V_VENT       ! Ventilation flow rate [AC/H]
  REAL, POINTER, DIMENSION(:)   :: XDESC_COP_RAT      ! Rated COP of the cooling system
  REAL, POINTER, DIMENSION(:)   :: XDESC_GREENROOF    ! Greenroof fraction
!
END TYPE BLD_DESC_t

TYPE(BLD_DESC_t), ALLOCATABLE, TARGET, SAVE :: BLD_DESC_MODEL(:)
!
INTEGER, POINTER :: NDESC_BLD=>NULL()
!$OMP THREADPRIVATE(NDESC_BLD)
INTEGER, POINTER :: NDESC_AGE=>NULL()
!$OMP THREADPRIVATE(NDESC_AGE)
INTEGER, POINTER :: NDESC_CODE=>NULL()
!$OMP THREADPRIVATE(NDESC_CODE)
INTEGER, POINTER :: NDESC_USE=>NULL()
!$OMP THREADPRIVATE(NDESC_USE)
INTEGER, POINTER :: NDESC_ROOF_LAYER=>NULL()
!$OMP THREADPRIVATE(NDESC_ROOF_LAYER)
INTEGER, POINTER :: NDESC_ROAD_LAYER=>NULL()
!$OMP THREADPRIVATE(NDESC_ROAD_LAYER)
INTEGER, POINTER :: NDESC_WALL_LAYER=>NULL()
!$OMP THREADPRIVATE(NDESC_WALL_LAYER)
INTEGER, POINTER :: NDESC_FLOOR_LAYER=>NULL()
!$OMP THREADPRIVATE(NDESC_FLOOR_LAYER)
INTEGER, POINTER, DIMENSION(:):: NDESC_BLD_LIST=>NULL()
!$OMP THREADPRIVATE(NDESC_BLD_LIST)
INTEGER, POINTER, DIMENSION(:):: NDESC_AGE_LIST=>NULL()
!$OMP THREADPRIVATE(NDESC_AGE_LIST)
INTEGER, POINTER, DIMENSION(:):: NDESC_CODE_LIST=>NULL()
!$OMP THREADPRIVATE(NDESC_CODE_LIST)
INTEGER, POINTER, DIMENSION(:):: NDESC_AGE_DATE=>NULL()
!$OMP THREADPRIVATE(NDESC_AGE_DATE)
INTEGER, POINTER, DIMENSION(:):: NDESC_USE_LIST=>NULL()
!$OMP THREADPRIVATE(NDESC_USE_LIST)
REAL, POINTER, DIMENSION(:)   :: XDESC_ALB_ROOF=>NULL()
!$OMP THREADPRIVATE(XDESC_ALB_ROOF)
REAL, POINTER, DIMENSION(:)   :: XDESC_ALB_ROAD=>NULL()
!$OMP THREADPRIVATE(XDESC_ALB_ROAD)
REAL, POINTER, DIMENSION(:)   :: XDESC_ALB_WALL=>NULL()
!$OMP THREADPRIVATE(XDESC_ALB_WALL)
REAL, POINTER, DIMENSION(:)   :: XDESC_EMIS_ROOF=>NULL()
!$OMP THREADPRIVATE(XDESC_EMIS_ROOF)
REAL, POINTER, DIMENSION(:)   :: XDESC_EMIS_ROAD=>NULL()
!$OMP THREADPRIVATE(XDESC_EMIS_ROAD)
REAL, POINTER, DIMENSION(:)   :: XDESC_EMIS_WALL=>NULL()
!$OMP THREADPRIVATE(XDESC_EMIS_WALL)
REAL, POINTER, DIMENSION(:)   :: XDESC_TCOOL_TARGET=>NULL()
!$OMP THREADPRIVATE(XDESC_TCOOL_TARGET)
REAL, POINTER, DIMENSION(:)   :: XDESC_THEAT_TARGET=>NULL()
!$OMP THREADPRIVATE(XDESC_THEAT_TARGET)
REAL, POINTER, DIMENSION(:)   :: XDESC_F_WASTE_CAN=>NULL()
!$OMP THREADPRIVATE(XDESC_F_WASTE_CAN)
REAL, POINTER, DIMENSION(:)   :: XDESC_EFF_HEAT=>NULL()
!$OMP THREADPRIVATE(XDESC_EFF_HEAT)
REAL, POINTER, DIMENSION(:,:) :: XDESC_HC_FLOOR=>NULL()
!$OMP THREADPRIVATE(XDESC_HC_FLOOR)
REAL, POINTER, DIMENSION(:,:) :: XDESC_TC_FLOOR=>NULL()
!$OMP THREADPRIVATE(XDESC_TC_FLOOR)
REAL, POINTER, DIMENSION(:,:) :: XDESC_D_FLOOR=>NULL()
!$OMP THREADPRIVATE(XDESC_D_FLOOR)
REAL, POINTER, DIMENSION(:,:) :: XDESC_HC_ROOF=>NULL()
!$OMP THREADPRIVATE(XDESC_HC_ROOF)
REAL, POINTER, DIMENSION(:,:) :: XDESC_TC_ROOF=>NULL()
!$OMP THREADPRIVATE(XDESC_TC_ROOF)
REAL, POINTER, DIMENSION(:,:) :: XDESC_D_ROOF=>NULL()
!$OMP THREADPRIVATE(XDESC_D_ROOF)
REAL, POINTER, DIMENSION(:,:) :: XDESC_HC_ROAD=>NULL()
!$OMP THREADPRIVATE(XDESC_HC_ROAD)
REAL, POINTER, DIMENSION(:,:) :: XDESC_TC_ROAD=>NULL()
!$OMP THREADPRIVATE(XDESC_TC_ROAD)
REAL, POINTER, DIMENSION(:,:) :: XDESC_D_ROAD=>NULL()
!$OMP THREADPRIVATE(XDESC_D_ROAD)
REAL, POINTER, DIMENSION(:,:) :: XDESC_HC_WALL=>NULL()
!$OMP THREADPRIVATE(XDESC_HC_WALL)
REAL, POINTER, DIMENSION(:,:) :: XDESC_TC_WALL=>NULL()
!$OMP THREADPRIVATE(XDESC_TC_WALL)
REAL, POINTER, DIMENSION(:,:) :: XDESC_D_WALL=>NULL()
!$OMP THREADPRIVATE(XDESC_D_WALL)
REAL, POINTER, DIMENSION(:)   :: XDESC_QIN=>NULL()
!$OMP THREADPRIVATE(XDESC_QIN)
REAL, POINTER, DIMENSION(:)   :: XDESC_QIN_FRAD=>NULL()
!$OMP THREADPRIVATE(XDESC_QIN_FRAD)
REAL, POINTER, DIMENSION(:)   :: XDESC_SHGC=>NULL()
!$OMP THREADPRIVATE(XDESC_SHGC)
REAL, POINTER, DIMENSION(:)   :: XDESC_U_WIN=>NULL()
!$OMP THREADPRIVATE(XDESC_U_WIN)
REAL, POINTER, DIMENSION(:)   :: XDESC_GR=>NULL()
!$OMP THREADPRIVATE(XDESC_GR)
REAL, POINTER, DIMENSION(:)   :: XDESC_SHGC_SH=>NULL()
!$OMP THREADPRIVATE(XDESC_SHGC_SH)
REAL, POINTER, DIMENSION(:)   :: XDESC_FLOOR_HEIGHT=>NULL()
!$OMP THREADPRIVATE(XDESC_FLOOR_HEIGHT)
REAL, POINTER, DIMENSION(:)   :: XDESC_INF=>NULL()
!$OMP THREADPRIVATE(XDESC_INF)
REAL, POINTER, DIMENSION(:):: XDESC_SHADE=>NULL()
!$OMP THREADPRIVATE(XDESC_SHADE)
REAL, POINTER, DIMENSION(:) :: XDESC_NATVENT=>NULL()
!$OMP THREADPRIVATE(XDESC_NATVENT)
REAL, POINTER, DIMENSION(:)   :: XDESC_F_WATER_COND=>NULL()
!$OMP THREADPRIVATE(XDESC_F_WATER_COND)
REAL, POINTER, DIMENSION(:)   :: XDESC_QIN_FLAT=>NULL()
!$OMP THREADPRIVATE(XDESC_QIN_FLAT)
REAL, POINTER, DIMENSION(:)   :: XDESC_HR_TARGET=>NULL()
!$OMP THREADPRIVATE(XDESC_HR_TARGET)
REAL, POINTER, DIMENSION(:)   :: XDESC_V_VENT=>NULL()
!$OMP THREADPRIVATE(XDESC_V_VENT)
REAL, POINTER, DIMENSION(:)   :: XDESC_COP_RAT=>NULL()
!$OMP THREADPRIVATE(XDESC_COP_RAT)
REAL, POINTER, DIMENSION(:)   :: XDESC_GREENROOF=>NULL()
!$OMP THREADPRIVATE(XDESC_GREENROOF)
!
CONTAINS

SUBROUTINE BLD_DESC_GOTO_MODEL(KFROM, KTO, LKFROM)
INTEGER, INTENT(IN) :: KFROM, KTO
LOGICAL, INTENT(IN) :: LKFROM
REAL(KIND=JPRB) :: ZHOOK_HANDLE
!
! Save current state for allocated arrays
!
IF (LKFROM) THEN
BLD_DESC_MODEL(KFROM)%NDESC_BLD_LIST=>NDESC_BLD_LIST
BLD_DESC_MODEL(KFROM)%NDESC_AGE_LIST=>NDESC_AGE_LIST
BLD_DESC_MODEL(KFROM)%NDESC_CODE_LIST=>NDESC_CODE_LIST
BLD_DESC_MODEL(KFROM)%NDESC_AGE_DATE=>NDESC_AGE_DATE
BLD_DESC_MODEL(KFROM)%NDESC_USE_LIST=>NDESC_USE_LIST
BLD_DESC_MODEL(KFROM)%XDESC_ALB_ROOF=>XDESC_ALB_ROOF
BLD_DESC_MODEL(KFROM)%XDESC_ALB_ROAD=>XDESC_ALB_ROAD
BLD_DESC_MODEL(KFROM)%XDESC_ALB_WALL=>XDESC_ALB_WALL
BLD_DESC_MODEL(KFROM)%XDESC_EMIS_ROOF=>XDESC_EMIS_ROOF
BLD_DESC_MODEL(KFROM)%XDESC_EMIS_ROAD=>XDESC_EMIS_ROAD
BLD_DESC_MODEL(KFROM)%XDESC_EMIS_WALL=>XDESC_EMIS_WALL
BLD_DESC_MODEL(KFROM)%XDESC_TCOOL_TARGET=>XDESC_TCOOL_TARGET
BLD_DESC_MODEL(KFROM)%XDESC_THEAT_TARGET=>XDESC_THEAT_TARGET
BLD_DESC_MODEL(KFROM)%XDESC_F_WASTE_CAN=>XDESC_F_WASTE_CAN
BLD_DESC_MODEL(KFROM)%XDESC_EFF_HEAT=>XDESC_EFF_HEAT
BLD_DESC_MODEL(KFROM)%XDESC_HC_FLOOR=>XDESC_HC_FLOOR
BLD_DESC_MODEL(KFROM)%XDESC_TC_FLOOR=>XDESC_TC_FLOOR
BLD_DESC_MODEL(KFROM)%XDESC_D_FLOOR=>XDESC_D_FLOOR
BLD_DESC_MODEL(KFROM)%XDESC_HC_ROOF=>XDESC_HC_ROOF
BLD_DESC_MODEL(KFROM)%XDESC_TC_ROOF=>XDESC_TC_ROOF
BLD_DESC_MODEL(KFROM)%XDESC_D_ROOF=>XDESC_D_ROOF
BLD_DESC_MODEL(KFROM)%XDESC_HC_ROAD=>XDESC_HC_ROAD
BLD_DESC_MODEL(KFROM)%XDESC_TC_ROAD=>XDESC_TC_ROAD
BLD_DESC_MODEL(KFROM)%XDESC_D_ROAD=>XDESC_D_ROAD
BLD_DESC_MODEL(KFROM)%XDESC_HC_WALL=>XDESC_HC_WALL
BLD_DESC_MODEL(KFROM)%XDESC_TC_WALL=>XDESC_TC_WALL
BLD_DESC_MODEL(KFROM)%XDESC_D_WALL=>XDESC_D_WALL
BLD_DESC_MODEL(KFROM)%XDESC_QIN=>XDESC_QIN
BLD_DESC_MODEL(KFROM)%XDESC_QIN_FRAD=>XDESC_QIN_FRAD
BLD_DESC_MODEL(KFROM)%XDESC_SHGC=>XDESC_SHGC
BLD_DESC_MODEL(KFROM)%XDESC_U_WIN=>XDESC_U_WIN
BLD_DESC_MODEL(KFROM)%XDESC_GR=>XDESC_GR
BLD_DESC_MODEL(KFROM)%XDESC_SHGC_SH=>XDESC_SHGC_SH
BLD_DESC_MODEL(KFROM)%XDESC_FLOOR_HEIGHT=>XDESC_FLOOR_HEIGHT
BLD_DESC_MODEL(KFROM)%XDESC_INF=>XDESC_INF
!
BLD_DESC_MODEL(KFROM)%XDESC_QIN_FLAT=>XDESC_QIN_FLAT
BLD_DESC_MODEL(KFROM)%XDESC_HR_TARGET=>XDESC_HR_TARGET
BLD_DESC_MODEL(KFROM)%XDESC_V_VENT=>XDESC_V_VENT
BLD_DESC_MODEL(KFROM)%XDESC_COP_RAT=>XDESC_COP_RAT
BLD_DESC_MODEL(KFROM)%XDESC_GREENROOF=>XDESC_GREENROOF
BLD_DESC_MODEL(KFROM)%XDESC_F_WATER_COND=>XDESC_F_WATER_COND
BLD_DESC_MODEL(KFROM)%XDESC_SHADE=>XDESC_SHADE
BLD_DESC_MODEL(KFROM)%XDESC_NATVENT=>XDESC_NATVENT
ENDIF
!
! Current model is set to model KTO
!
IF (LHOOK) CALL DR_HOOK('MODD_BLD_DESCRIPTION:BLD_DESC_GOTO_MODEL',0,ZHOOK_HANDLE)
NDESC_BLD=>BLD_DESC_MODEL(KTO)%NDESC_BLD
NDESC_AGE=>BLD_DESC_MODEL(KTO)%NDESC_AGE
NDESC_CODE=>BLD_DESC_MODEL(KTO)%NDESC_CODE
NDESC_USE=>BLD_DESC_MODEL(KTO)%NDESC_USE
NDESC_ROOF_LAYER=>BLD_DESC_MODEL(KTO)%NDESC_ROOF_LAYER
NDESC_ROAD_LAYER=>BLD_DESC_MODEL(KTO)%NDESC_ROAD_LAYER
NDESC_WALL_LAYER=>BLD_DESC_MODEL(KTO)%NDESC_WALL_LAYER
NDESC_FLOOR_LAYER=>BLD_DESC_MODEL(KTO)%NDESC_FLOOR_LAYER
NDESC_BLD_LIST=>BLD_DESC_MODEL(KTO)%NDESC_BLD_LIST
NDESC_AGE_LIST=>BLD_DESC_MODEL(KTO)%NDESC_AGE_LIST
NDESC_CODE_LIST=>BLD_DESC_MODEL(KTO)%NDESC_CODE_LIST
NDESC_AGE_DATE=>BLD_DESC_MODEL(KTO)%NDESC_AGE_DATE
NDESC_USE_LIST=>BLD_DESC_MODEL(KTO)%NDESC_USE_LIST
XDESC_ALB_ROOF=>BLD_DESC_MODEL(KTO)%XDESC_ALB_ROOF
XDESC_ALB_ROAD=>BLD_DESC_MODEL(KTO)%XDESC_ALB_ROAD
XDESC_ALB_WALL=>BLD_DESC_MODEL(KTO)%XDESC_ALB_WALL
XDESC_EMIS_ROOF=>BLD_DESC_MODEL(KTO)%XDESC_EMIS_ROOF
XDESC_EMIS_ROAD=>BLD_DESC_MODEL(KTO)%XDESC_EMIS_ROAD
XDESC_EMIS_WALL=>BLD_DESC_MODEL(KTO)%XDESC_EMIS_WALL
XDESC_TCOOL_TARGET=>BLD_DESC_MODEL(KTO)%XDESC_TCOOL_TARGET
XDESC_THEAT_TARGET=>BLD_DESC_MODEL(KTO)%XDESC_THEAT_TARGET
XDESC_F_WASTE_CAN=>BLD_DESC_MODEL(KTO)%XDESC_F_WASTE_CAN
XDESC_EFF_HEAT=>BLD_DESC_MODEL(KTO)%XDESC_EFF_HEAT
XDESC_HC_FLOOR=>BLD_DESC_MODEL(KTO)%XDESC_HC_FLOOR
XDESC_TC_FLOOR=>BLD_DESC_MODEL(KTO)%XDESC_TC_FLOOR
XDESC_D_FLOOR=>BLD_DESC_MODEL(KTO)%XDESC_D_FLOOR
XDESC_HC_ROOF=>BLD_DESC_MODEL(KTO)%XDESC_HC_ROOF
XDESC_TC_ROOF=>BLD_DESC_MODEL(KTO)%XDESC_TC_ROOF
XDESC_D_ROOF=>BLD_DESC_MODEL(KTO)%XDESC_D_ROOF
XDESC_HC_ROAD=>BLD_DESC_MODEL(KTO)%XDESC_HC_ROAD
XDESC_TC_ROAD=>BLD_DESC_MODEL(KTO)%XDESC_TC_ROAD
XDESC_D_ROAD=>BLD_DESC_MODEL(KTO)%XDESC_D_ROAD
XDESC_HC_WALL=>BLD_DESC_MODEL(KTO)%XDESC_HC_WALL
XDESC_TC_WALL=>BLD_DESC_MODEL(KTO)%XDESC_TC_WALL
XDESC_D_WALL=>BLD_DESC_MODEL(KTO)%XDESC_D_WALL
XDESC_QIN=>BLD_DESC_MODEL(KTO)%XDESC_QIN
XDESC_QIN_FRAD=>BLD_DESC_MODEL(KTO)%XDESC_QIN_FRAD
XDESC_SHGC=>BLD_DESC_MODEL(KTO)%XDESC_SHGC
XDESC_U_WIN=>BLD_DESC_MODEL(KTO)%XDESC_U_WIN
XDESC_GR=>BLD_DESC_MODEL(KTO)%XDESC_GR
XDESC_SHGC_SH=>BLD_DESC_MODEL(KTO)%XDESC_SHGC_SH
XDESC_FLOOR_HEIGHT=>BLD_DESC_MODEL(KTO)%XDESC_FLOOR_HEIGHT
XDESC_INF=>BLD_DESC_MODEL(KTO)%XDESC_INF
XDESC_SHADE=>BLD_DESC_MODEL(KTO)%XDESC_SHADE
XDESC_NATVENT=>BLD_DESC_MODEL(KTO)%XDESC_NATVENT
XDESC_F_WATER_COND=>BLD_DESC_MODEL(KTO)%XDESC_F_WATER_COND
XDESC_QIN_FLAT=>BLD_DESC_MODEL(KTO)%XDESC_QIN_FLAT
XDESC_HR_TARGET=>BLD_DESC_MODEL(KTO)%XDESC_HR_TARGET
XDESC_V_VENT=>BLD_DESC_MODEL(KTO)%XDESC_V_VENT
XDESC_COP_RAT=>BLD_DESC_MODEL(KTO)%XDESC_COP_RAT
XDESC_GREENROOF=>BLD_DESC_MODEL(KTO)%XDESC_GREENROOF
IF (LHOOK) CALL DR_HOOK('MODD_BLD_DESCRIPTION:BLD_DESC_GOTO_MODEL',1,ZHOOK_HANDLE)
!
END SUBROUTINE BLD_DESC_GOTO_MODEL
!
SUBROUTINE BLD_DESC_ALLOC(KMODEL)
INTEGER, INTENT(IN) :: KMODEL
INTEGER :: J
REAL(KIND=JPRB) :: ZHOOK_HANDLE
IF (LHOOK) CALL DR_HOOK("MODD_BLD_DESCRIPTION:BLD_DESC_ALLOC",0,ZHOOK_HANDLE)
ALLOCATE(BLD_DESC_MODEL(KMODEL))
DO J=1,KMODEL
  NULLIFY(BLD_DESC_MODEL(J)%NDESC_BLD_LIST)
  NULLIFY(BLD_DESC_MODEL(J)%NDESC_CODE_LIST)
  NULLIFY(BLD_DESC_MODEL(J)%NDESC_AGE_LIST)
  NULLIFY(BLD_DESC_MODEL(J)%NDESC_AGE_DATE)
  NULLIFY(BLD_DESC_MODEL(J)%NDESC_USE_LIST)
  NULLIFY(BLD_DESC_MODEL(J)%XDESC_ALB_ROOF)
  NULLIFY(BLD_DESC_MODEL(J)%XDESC_ALB_ROAD)
  NULLIFY(BLD_DESC_MODEL(J)%XDESC_ALB_WALL)
  NULLIFY(BLD_DESC_MODEL(J)%XDESC_EMIS_ROOF)
  NULLIFY(BLD_DESC_MODEL(J)%XDESC_EMIS_ROAD)
  NULLIFY(BLD_DESC_MODEL(J)%XDESC_EMIS_WALL)
  NULLIFY(BLD_DESC_MODEL(J)%XDESC_TCOOL_TARGET)
  NULLIFY(BLD_DESC_MODEL(J)%XDESC_THEAT_TARGET)
  NULLIFY(BLD_DESC_MODEL(J)%XDESC_F_WASTE_CAN)  
  NULLIFY(BLD_DESC_MODEL(J)%XDESC_EFF_HEAT)
  NULLIFY(BLD_DESC_MODEL(J)%XDESC_HC_FLOOR)
  NULLIFY(BLD_DESC_MODEL(J)%XDESC_TC_FLOOR)
  NULLIFY(BLD_DESC_MODEL(J)%XDESC_D_FLOOR)
  NULLIFY(BLD_DESC_MODEL(J)%XDESC_HC_ROOF)
  NULLIFY(BLD_DESC_MODEL(J)%XDESC_TC_ROOF)
  NULLIFY(BLD_DESC_MODEL(J)%XDESC_D_ROOF)
  NULLIFY(BLD_DESC_MODEL(J)%XDESC_HC_ROAD)
  NULLIFY(BLD_DESC_MODEL(J)%XDESC_TC_ROAD)
  NULLIFY(BLD_DESC_MODEL(J)%XDESC_D_ROAD)
  NULLIFY(BLD_DESC_MODEL(J)%XDESC_HC_WALL)
  NULLIFY(BLD_DESC_MODEL(J)%XDESC_TC_WALL)
  NULLIFY(BLD_DESC_MODEL(J)%XDESC_D_WALL)
  NULLIFY(BLD_DESC_MODEL(J)%XDESC_QIN)
  NULLIFY(BLD_DESC_MODEL(J)%XDESC_QIN_FRAD)
  NULLIFY(BLD_DESC_MODEL(J)%XDESC_SHGC) 
  NULLIFY(BLD_DESC_MODEL(J)%XDESC_U_WIN)
  NULLIFY(BLD_DESC_MODEL(J)%XDESC_GR)
  NULLIFY(BLD_DESC_MODEL(J)%XDESC_FLOOR_HEIGHT)
  NULLIFY(BLD_DESC_MODEL(J)%XDESC_INF)
  NULLIFY(BLD_DESC_MODEL(J)%XDESC_F_WATER_COND)
  NULLIFY(BLD_DESC_MODEL(J)%XDESC_QIN_FLAT)
  NULLIFY(BLD_DESC_MODEL(J)%XDESC_HR_TARGET)
  NULLIFY(BLD_DESC_MODEL(J)%XDESC_V_VENT)
  NULLIFY(BLD_DESC_MODEL(J)%XDESC_COP_RAT)
  NULLIFY(BLD_DESC_MODEL(J)%XDESC_GREENROOF)
  NULLIFY(BLD_DESC_MODEL(J)%XDESC_SHADE)
  NULLIFY(BLD_DESC_MODEL(J)%XDESC_NATVENT)
ENDDO
BLD_DESC_MODEL(:)%NDESC_BLD=0
BLD_DESC_MODEL(:)%NDESC_AGE=0
BLD_DESC_MODEL(:)%NDESC_CODE=0
BLD_DESC_MODEL(:)%NDESC_USE=0
BLD_DESC_MODEL(:)%NDESC_ROOF_LAYER=0
BLD_DESC_MODEL(:)%NDESC_ROAD_LAYER=0
BLD_DESC_MODEL(:)%NDESC_WALL_LAYER=0
BLD_DESC_MODEL(:)%NDESC_FLOOR_LAYER=0
IF (LHOOK) CALL DR_HOOK("MODD_BLD_DESCRIPTION:BLD_DESC_ALLOC",1,ZHOOK_HANDLE)
END SUBROUTINE BLD_DESC_ALLOC
!
SUBROUTINE BLD_DESC_DEALLO
REAL(KIND=JPRB) :: ZHOOK_HANDLE
IF (LHOOK) CALL DR_HOOK("MODD_BLD_DESCRIPTION:BLD_DESC_DEALLO",0,ZHOOK_HANDLE)
IF (ALLOCATED(BLD_DESC_MODEL)) DEALLOCATE(BLD_DESC_MODEL)
IF (LHOOK) CALL DR_HOOK("MODD_BLD_DESCRIPTION:BLD_DESC_DEALLO",1,ZHOOK_HANDLE)
END SUBROUTINE BLD_DESC_DEALLO
!
END MODULE MODD_BLD_DESCRIPTION
