!SURFEX_LIC Copyright 1994-2014 Meteo-France 
!SURFEX_LIC This is part of the SURFEX software governed by the CeCILL-C  licence
!SURFEX_LIC version 1. See LICENSE, CeCILL-C_V1-en.txt and CeCILL-C_V1-fr.txt
!SURFEX_LIC for details. version 1.
!     ######################
      MODULE MODD_DIAG_SURF_ATM_n
!     ######################
!
!!****  *MODD_DIAG_SURF_ATM - declaration of diagnostics for the surface
!!
!!    PURPOSE
!!    -------
!
!!
!!**  IMPLICIT ARGUMENTS
!!    ------------------
!!      None 
!!
!!    REFERENCE
!!    ---------
!!
!!    AUTHOR
!!    ------
!!	V. Masson   *Meteo France*
!!
!!    MODIFICATIONS
!!    -------------
!!      Original       01/2004
!!      Modified    01/2006 : sea flux parameterization.
!!      Modified    04/2009 : precip for/from restart file.
!!      Modified    08/2009 : BUDGETC for all tiles
!
!*       0.   DECLARATIONS
!             ------------
!
USE MODD_TYPE_DATE_SURF
!
!
USE YOMHOOK   ,ONLY : LHOOK,   DR_HOOK
USE PARKIND1  ,ONLY : JPRB
!
IMPLICIT NONE

TYPE DIAG_SURF_ATM_t
!------------------------------------------------------------------------------
!
  REAL    :: XDIAG_TSTEP  ! time step for diagnostics writing
!
  INTEGER :: N2M          ! flag for 2 meters (and 10 meters) quantities
  LOGICAL :: L2M_MIN_ZS   ! flag for 2 meters quantities evaluated on
!                         ! the minimum orographyy of the grid 
  LOGICAL :: LSURF_BUDGET ! flag for surface energy budget
  LOGICAL :: LRAD_BUDGET  ! flag for radiative energy budget      
  LOGICAL :: LCOEF        ! flag for transfer coefficients
  LOGICAL :: LSURF_VARS   ! flag for surface variables
  LOGICAL :: LFRAC        ! flag for writing fractions of each four tiles
  LOGICAL :: LDIAG_GRID   ! flag for mean grid diag
  LOGICAL :: LSURF_BUDGETC       ! flag for surface cumulated energy budget
  LOGICAL :: LRESET_BUDGETC      ! flag for surface cumulated energy budget
  LOGICAL :: LREAD_BUDGETC       ! flag for surface cumulated energy budget
  LOGICAL :: LPROVAR_TO_DIAG     ! switch to write (or not) prognostic variable
                                 ! and allows puting field in diagnostics 
  LOGICAL    :: LSELECT          ! switch to control which fields are written
                                 ! (only those whose naem appears in in text array)
!  
  TYPE(DATE_TIME):: TIME_BUDGETC
!
!* variables for each tile
!
  REAL, POINTER, DIMENSION(:,:) :: XRI_TILE     ! Bulk-Richardson number           (-)
  REAL, POINTER, DIMENSION(:,:) :: XCD_TILE     ! drag coefficient for wind        (W/s2)
  REAL, POINTER, DIMENSION(:,:) :: XCH_TILE     ! drag coefficient for heat        (W/s)
  REAL, POINTER, DIMENSION(:,:) :: XCE_TILE     ! drag coefficient for vapor       (W/s/K)
  REAL, POINTER, DIMENSION(:,:) :: XRN_TILE     ! net radiation at surface         (W/m2)
  REAL, POINTER, DIMENSION(:,:) :: XH_TILE      ! sensible heat flux               (W/m2)
  REAL, POINTER, DIMENSION(:,:) :: XLE_TILE     ! total latent heat flux           (W/m2) 
  REAL, POINTER, DIMENSION(:,:) :: XLEI_TILE    ! sublimation latent heat flux     (W/m2) 
  REAL, POINTER, DIMENSION(:,:) :: XGFLUX_TILE  ! net soil-vegetation flux         (W/m2)
  REAL, POINTER, DIMENSION(:,:) :: XTS_TILE     ! surface temperature              (K)
  REAL, POINTER, DIMENSION(:,:) :: XT2M_TILE    ! air temperature at 2 meters      (K)
  REAL, POINTER, DIMENSION(:,:) :: XT2M_MIN_TILE! Minimum air temperature at 2 meters (K)
  REAL, POINTER, DIMENSION(:,:) :: XT2M_MAX_TILE! Maximum air temperature at 2 meters (K)
  REAL, POINTER, DIMENSION(:,:) :: XQ2M_TILE    ! air humidity at 2 meters         (kg/kg)
  REAL, POINTER, DIMENSION(:,:) :: XHU2M_TILE   ! air relative humidity at 2 meters(-)
  REAL, POINTER, DIMENSION(:,:) :: XHU2M_MIN_TILE! Minimum air relative humidity at 2 meters(-)
  REAL, POINTER, DIMENSION(:,:) :: XHU2M_MAX_TILE! Maximum air relative humidity at 2 meters(-)
  REAL, POINTER, DIMENSION(:,:) :: XZON10M_TILE ! zonal wind at 10 meters          (m/s)
  REAL, POINTER, DIMENSION(:,:) :: XMER10M_TILE ! meridian wind at 10 meters       (m/s)
  REAL, POINTER, DIMENSION(:,:) :: XWIND10M_TILE! wind at 10 meters                (m/s)
  REAL, POINTER, DIMENSION(:,:) :: XWIND10M_MAX_TILE ! Maximumwind at 10 meters    (m/s)
  REAL, POINTER, DIMENSION(:,:) :: XQS_TILE
  REAL, POINTER, DIMENSION(:,:) :: XZ0_TILE     ! roughness length for momentum    (m)
  REAL, POINTER, DIMENSION(:,:) :: XZ0H_TILE    ! roughness length for heat        (m)
  REAL, POINTER, DIMENSION(:,:) :: XSWD_TILE    ! short wave downward radiation (W/m2)
  REAL, POINTER, DIMENSION(:,:) :: XSWU_TILE    ! short wave upward radiation (W/m2)
  REAL, POINTER, DIMENSION(:,:) :: XLWD_TILE    ! longt wave downward radiation (W/m2)
  REAL, POINTER, DIMENSION(:,:) :: XLWU_TILE    ! longt wave upward radiation (W/m2)
  REAL, POINTER, DIMENSION(:,:,:) :: XSWBD_TILE ! short wave downward radiation by spectral band(W/m2)
  REAL, POINTER, DIMENSION(:,:,:) :: XSWBU_TILE ! short wave upward radiation by spectral band(W/m2)
  REAL, POINTER, DIMENSION(:,:) :: XFMU_TILE    ! zonal friction
  REAL, POINTER, DIMENSION(:,:) :: XFMV_TILE    ! meridian friction
!
!* Cumulated variables for each tile
!
  REAL, POINTER, DIMENSION(:,:) :: XRNC_TILE     ! net radiation at surface         (J/m2)
  REAL, POINTER, DIMENSION(:,:) :: XHC_TILE      ! sensible heat flux               (J/m2)
  REAL, POINTER, DIMENSION(:,:) :: XLEC_TILE     ! total latent heat flux           (J/m2) 
  REAL, POINTER, DIMENSION(:,:) :: XLEIC_TILE    ! sublimation latent heat flux     (J/m2) 
  REAL, POINTER, DIMENSION(:,:) :: XGFLUXC_TILE  ! net soil-vegetation flux         (J/m2)
  REAL, POINTER, DIMENSION(:,:) :: XSWDC_TILE    ! short wave downward radiation    (J/m2)
  REAL, POINTER, DIMENSION(:,:) :: XSWUC_TILE    ! short wave upward radiation      (J/m2)
  REAL, POINTER, DIMENSION(:,:) :: XLWDC_TILE    ! longt wave downward radiation    (J/m2)
  REAL, POINTER, DIMENSION(:,:) :: XLWUC_TILE    ! longt wave upward radiation      (J/m2)
  REAL, POINTER, DIMENSION(:,:) :: XFMUC_TILE    ! zonal friction
  REAL, POINTER, DIMENSION(:,:) :: XFMVC_TILE    ! meridian friction
!
!* averaged variables
!
  REAL, POINTER, DIMENSION(:)   :: XAVG_RI      ! Bulk-Richardson number           (-)
  REAL, POINTER, DIMENSION(:)   :: XAVG_CD       ! drag coefficient for wind        (W/s2)
  REAL, POINTER, DIMENSION(:)   :: XAVG_CH       ! drag coefficient for heat        (W/s)
  REAL, POINTER, DIMENSION(:)   :: XAVG_CE       ! drag coefficient for vapor       (W/s/K)
  REAL, POINTER, DIMENSION(:)   :: XAVG_RN      ! net radiation at surface         (W/m2)
  REAL, POINTER, DIMENSION(:)   :: XAVG_H       ! sensible heat flux               (W/m2)
  REAL, POINTER, DIMENSION(:)   :: XAVG_LE      ! total latent heat flux           (W/m2) 
  REAL, POINTER, DIMENSION(:)   :: XAVG_LEI     ! sublimation latent heat flux     (W/m2) 
  REAL, POINTER, DIMENSION(:)   :: XAVG_GFLUX   ! net soil-vegetation flux         (W/m2)
  REAL, POINTER, DIMENSION(:)   :: XAVG_TS      ! surface temperature              (K)
  REAL, POINTER, DIMENSION(:)   :: XAVG_T2M     ! air temperature at 2 meters      (K)
  REAL, POINTER, DIMENSION(:)   :: XAVG_Q2M     ! air humidity at 2 meters         (kg/kg)
  REAL, POINTER, DIMENSION(:)   :: XAVG_HU2M    ! air relative humidity at 2 meters(-)
  REAL, POINTER, DIMENSION(:)   :: XAVG_ZON10M  ! zonal wind at 10 meters          (m/s)
  REAL, POINTER, DIMENSION(:)   :: XAVG_MER10M  ! meridian wind at 10 meters       (m/s)
  REAL, POINTER, DIMENSION(:)   :: XAVG_SFCO2   ! CO2 flux                         (kg/m2/s)  
  REAL, POINTER, DIMENSION(:)   :: XAVG_T2M_MIN_ZS ! air temperature at 2 meters   (K)
  REAL, POINTER, DIMENSION(:)   :: XAVG_Q2M_MIN_ZS ! air humidity at 2 meters      (kg/kg)
  REAL, POINTER, DIMENSION(:)   :: XAVG_HU2M_MIN_ZS! air relative humidity at 2 m  (-)
  REAL, POINTER, DIMENSION(:)   :: XPS          ! air pressure at the surface      (Pa)
  REAL, POINTER, DIMENSION(:)   :: XRHOA        ! air density  at the surface      (kg/m3)
  REAL, POINTER, DIMENSION(:)   :: XAVG_QS
  REAL, POINTER, DIMENSION(:)   :: XAVG_Z0      ! roughness length for momentum    (m)
  REAL, POINTER, DIMENSION(:)   :: XAVG_Z0H     ! roughness length for heat        (m)
  REAL, POINTER, DIMENSION(:)   :: XAVG_SWD     ! short wave downward radiation (W/m2)
  REAL, POINTER, DIMENSION(:)   :: XAVG_SWU     ! short wave upward radiation (W/m2)
  REAL, POINTER, DIMENSION(:)   :: XAVG_LWD     ! longt wave downward radiation (W/m2)
  REAL, POINTER, DIMENSION(:)   :: XAVG_LWU     ! longt wave upward radiation (W/m2)
  REAL, POINTER, DIMENSION(:,:) :: XAVG_SWBD    ! short wave downward radiation by spectral band(W/m2)
  REAL, POINTER, DIMENSION(:,:) :: XAVG_SWBU    ! short wave upward radiation by spectral band(W/m2)
  REAL, POINTER, DIMENSION(:)   :: XAVG_FMU     ! zonal friction
  REAL, POINTER, DIMENSION(:)   :: XAVG_FMV     ! meridian friction
  REAL, POINTER, DIMENSION(:)   :: XSSO_FMU     ! zonal friction    (with SSO)     (Pa)
  REAL, POINTER, DIMENSION(:)   :: XSSO_FMV     ! meridian friction (with SSO)     (Pa)
!
  REAL, POINTER, DIMENSION(:)   :: XDIAG_UREF   ! reference height for momentum    (m)
  REAL, POINTER, DIMENSION(:)   :: XDIAG_ZREF   ! reference height for heat        (m)
  REAL, POINTER, DIMENSION(:)   :: XDIAG_TRAD   ! radiative temperature at t       (K)
  REAL, POINTER, DIMENSION(:)   :: XDIAG_EMIS   ! surface emissivity at t          (-)
!
  REAL, POINTER, DIMENSION(:)   :: XAVG_T2M_MIN ! Minimun air temperature at 2 meters      (K)
  REAL, POINTER, DIMENSION(:)   :: XAVG_T2M_MAX ! Maximum air temperature at 2 meters      (K)
  REAL, POINTER, DIMENSION(:)   :: XAVG_HU2M_MIN! Minimun air relative humidity at 2 meters(-)
  REAL, POINTER, DIMENSION(:)   :: XAVG_HU2M_MAX! Maximum air relative humidity at 2 meters(-)
  REAL, POINTER, DIMENSION(:)   :: XAVG_WIND10M ! wind at 10 meters                      (m/s)
  REAL, POINTER, DIMENSION(:)   :: XAVG_WIND10M_MAX ! Maximum wind at 10 meters          (m/s)
!
!* cumulated averaged variables
!
  REAL, POINTER, DIMENSION(:)   :: XAVG_RNC      ! net radiation at surface         (J/m2)
  REAL, POINTER, DIMENSION(:)   :: XAVG_HC       ! sensible heat flux               (J/m2)
  REAL, POINTER, DIMENSION(:)   :: XAVG_LEC      ! total latent heat flux           (J/m2) 
  REAL, POINTER, DIMENSION(:)   :: XAVG_LEIC     ! sublimation latent heat flux     (J/m2) 
  REAL, POINTER, DIMENSION(:)   :: XAVG_GFLUXC   ! net soil-vegetation flux         (J/m2)
  REAL, POINTER, DIMENSION(:)   :: XAVG_SWDC     ! short wave downward radiation    (J/m2)
  REAL, POINTER, DIMENSION(:)   :: XAVG_SWUC     ! short wave upward radiation      (J/m2)
  REAL, POINTER, DIMENSION(:)   :: XAVG_LWDC     ! longt wave downward radiation    (J/m2)
  REAL, POINTER, DIMENSION(:)   :: XAVG_LWUC     ! longt wave upward radiation      (J/m2)
  REAL, POINTER, DIMENSION(:)   :: XAVG_FMUC     ! zonal friction
  REAL, POINTER, DIMENSION(:)   :: XAVG_FMVC     ! meridian friction
!
!* restart variables (for ARPEGE/ALADAIN)
!
  REAL, POINTER, DIMENSION(:) :: XRW_RAIN       ! Init/End rainfall rate   (kg/m2/s)
  REAL, POINTER, DIMENSION(:) :: XRW_SNOW       ! Init/End snowfall rate   (kg/m2/s)
!                                   
  CHARACTER(LEN=12), POINTER, DIMENSION(:) :: CSELECT  ! Name of ouput fields if LSELECT=true
!
!------------------------------------------------------------------------------
!

END TYPE DIAG_SURF_ATM_t

TYPE(DIAG_SURF_ATM_t), ALLOCATABLE, TARGET, SAVE :: DIAG_SURF_ATM_MODEL(:)

REAL, POINTER :: XDIAG_TSTEP=>NULL()
!$OMP THREADPRIVATE(XDIAG_TSTEP)
INTEGER, POINTER :: N2M=>NULL()
!$OMP THREADPRIVATE(N2M)
LOGICAL, POINTER :: L2M_MIN_ZS=>NULL()
!$OMP THREADPRIVATE(L2M_MIN_ZS)
LOGICAL, POINTER :: LSURF_BUDGET=>NULL()
!$OMP THREADPRIVATE(LSURF_BUDGET)
LOGICAL, POINTER :: LRAD_BUDGET=>NULL()
!$OMP THREADPRIVATE(LRAD_BUDGET)
LOGICAL, POINTER :: LCOEF=>NULL()
!$OMP THREADPRIVATE(LCOEF)
LOGICAL, POINTER :: LSURF_VARS=>NULL()
!$OMP THREADPRIVATE(LSURF_VARS)
LOGICAL, POINTER :: LFRAC=>NULL()
!$OMP THREADPRIVATE(LFRAC)
LOGICAL, POINTER :: LDIAG_GRID=>NULL()
!$OMP THREADPRIVATE(LDIAG_GRID)
LOGICAL, POINTER :: LSURF_BUDGETC=>NULL()
!$OMP THREADPRIVATE(LSURF_BUDGETC)
LOGICAL, POINTER :: LRESET_BUDGETC=>NULL()
!$OMP THREADPRIVATE(LRESET_BUDGETC)
LOGICAL, POINTER :: LREAD_BUDGETC=>NULL()
!$OMP THREADPRIVATE(LREAD_BUDGETC)
LOGICAL, POINTER :: LPROVAR_TO_DIAG=>NULL()
!$OMP THREADPRIVATE(LPROVAR_TO_DIAG)
LOGICAL, POINTER :: LSELECT=>NULL()
!$OMP THREADPRIVATE(LSELECT)
 CHARACTER(LEN=12), DIMENSION(:), POINTER :: CSELECT=>NULL()
!$OMP THREADPRIVATE(CSELECT)
TYPE(DATE_TIME), POINTER :: TIME_BUDGETC=>NULL()
!$OMP THREADPRIVATE(TIME_BUDGETC)
REAL, POINTER, DIMENSION(:,:) :: XRI_TILE=>NULL()
!$OMP THREADPRIVATE(XRI_TILE)
REAL, POINTER, DIMENSION(:,:) :: XCD_TILE=>NULL()
!$OMP THREADPRIVATE(XCD_TILE)
REAL, POINTER, DIMENSION(:,:) :: XCH_TILE=>NULL()
!$OMP THREADPRIVATE(XCH_TILE)
REAL, POINTER, DIMENSION(:,:) :: XCE_TILE=>NULL()
!$OMP THREADPRIVATE(XCE_TILE)
REAL, POINTER, DIMENSION(:,:) :: XRN_TILE=>NULL()
!$OMP THREADPRIVATE(XRN_TILE)
REAL, POINTER, DIMENSION(:,:) :: XH_TILE=>NULL()
!$OMP THREADPRIVATE(XH_TILE)
REAL, POINTER, DIMENSION(:,:) :: XLE_TILE=>NULL()
!$OMP THREADPRIVATE(XLE_TILE)
REAL, POINTER, DIMENSION(:,:) :: XLEI_TILE=>NULL()
!$OMP THREADPRIVATE(XLEI_TILE)
REAL, POINTER, DIMENSION(:,:) :: XGFLUX_TILE=>NULL()
!$OMP THREADPRIVATE(XGFLUX_TILE)
REAL, POINTER, DIMENSION(:,:) :: XTS_TILE=>NULL()
!$OMP THREADPRIVATE(XTS_TILE)
REAL, POINTER, DIMENSION(:,:) :: XT2M_TILE=>NULL()
!$OMP THREADPRIVATE(XT2M_TILE)
REAL, POINTER, DIMENSION(:,:) :: XT2M_MAX_TILE=>NULL()
!$OMP THREADPRIVATE(XT2M_MAX_TILE)
REAL, POINTER, DIMENSION(:,:) :: XT2M_MIN_TILE=>NULL()
!$OMP THREADPRIVATE(XT2M_MIN_TILE)
REAL, POINTER, DIMENSION(:,:) :: XQ2M_TILE=>NULL()
!$OMP THREADPRIVATE(XQ2M_TILE)
REAL, POINTER, DIMENSION(:,:) :: XHU2M_TILE=>NULL()
!$OMP THREADPRIVATE(XHU2M_TILE)
REAL, POINTER, DIMENSION(:,:) :: XHU2M_MAX_TILE=>NULL()
!$OMP THREADPRIVATE(XHU2M_MAX_TILE)
REAL, POINTER, DIMENSION(:,:) :: XHU2M_MIN_TILE=>NULL()
!$OMP THREADPRIVATE(XHU2M_MIN_TILE)
REAL, POINTER, DIMENSION(:,:) :: XZON10M_TILE=>NULL()
!$OMP THREADPRIVATE(XZON10M_TILE)
REAL, POINTER, DIMENSION(:,:) :: XMER10M_TILE=>NULL()
!$OMP THREADPRIVATE(XMER10M_TILE)
REAL, POINTER, DIMENSION(:,:) :: XWIND10M_TILE=>NULL()
!$OMP THREADPRIVATE(XWIND10M_TILE)
REAL, POINTER, DIMENSION(:,:) :: XWIND10M_MAX_TILE=>NULL()
!$OMP THREADPRIVATE(XWIND10M_MAX_TILE)
REAL, POINTER, DIMENSION(:,:) :: XQS_TILE=>NULL()
!$OMP THREADPRIVATE(XQS_TILE)
REAL, POINTER, DIMENSION(:,:) :: XZ0_TILE=>NULL()
!$OMP THREADPRIVATE(XZ0_TILE)
REAL, POINTER, DIMENSION(:,:) :: XZ0H_TILE=>NULL()
!$OMP THREADPRIVATE(XZ0H_TILE)
REAL, POINTER, DIMENSION(:,:) :: XSWD_TILE=>NULL()
!$OMP THREADPRIVATE(XSWD_TILE)
REAL, POINTER, DIMENSION(:,:) :: XSWU_TILE=>NULL()
!$OMP THREADPRIVATE(XSWU_TILE)
REAL, POINTER, DIMENSION(:,:) :: XLWD_TILE=>NULL()
!$OMP THREADPRIVATE(XLWD_TILE)
REAL, POINTER, DIMENSION(:,:) :: XLWU_TILE=>NULL()
!$OMP THREADPRIVATE(XLWU_TILE)
REAL, POINTER, DIMENSION(:,:,:) :: XSWBD_TILE=>NULL()
!$OMP THREADPRIVATE(XSWBD_TILE)
REAL, POINTER, DIMENSION(:,:,:) :: XSWBU_TILE=>NULL()
!$OMP THREADPRIVATE(XSWBU_TILE)
REAL, POINTER, DIMENSION(:,:) :: XFMU_TILE=>NULL()
!$OMP THREADPRIVATE(XFMU_TILE)
REAL, POINTER, DIMENSION(:,:) :: XFMV_TILE=>NULL()
!$OMP THREADPRIVATE(XFMV_TILE)
REAL, POINTER, DIMENSION(:,:) :: XRNC_TILE=>NULL()
!$OMP THREADPRIVATE(XRNC_TILE)
REAL, POINTER, DIMENSION(:,:) :: XHC_TILE=>NULL()
!$OMP THREADPRIVATE(XHC_TILE)
REAL, POINTER, DIMENSION(:,:) :: XLEC_TILE=>NULL()
!$OMP THREADPRIVATE(XLEC_TILE)
REAL, POINTER, DIMENSION(:,:) :: XLEIC_TILE=>NULL()
!$OMP THREADPRIVATE(XLEIC_TILE)
REAL, POINTER, DIMENSION(:,:) :: XGFLUXC_TILE=>NULL()
!$OMP THREADPRIVATE(XGFLUXC_TILE)
REAL, POINTER, DIMENSION(:,:) :: XSWDC_TILE=>NULL()
!$OMP THREADPRIVATE(XSWDC_TILE)
REAL, POINTER, DIMENSION(:,:) :: XSWUC_TILE=>NULL()
!$OMP THREADPRIVATE(XSWUC_TILE)
REAL, POINTER, DIMENSION(:,:) :: XLWDC_TILE=>NULL()
!$OMP THREADPRIVATE(XLWDC_TILE)
REAL, POINTER, DIMENSION(:,:) :: XLWUC_TILE=>NULL()
!$OMP THREADPRIVATE(XLWUC_TILE)
REAL, POINTER, DIMENSION(:,:) :: XFMUC_TILE=>NULL()
!$OMP THREADPRIVATE(XFMUC_TILE)
REAL, POINTER, DIMENSION(:,:) :: XFMVC_TILE=>NULL()
!$OMP THREADPRIVATE(XFMVC_TILE)
REAL, POINTER, DIMENSION(:)   :: XAVG_RI=>NULL()
!$OMP THREADPRIVATE(XAVG_RI)
REAL, POINTER, DIMENSION(:)   :: XAVG_CD=>NULL()
!$OMP THREADPRIVATE(XAVG_CD)
REAL, POINTER, DIMENSION(:)   :: XAVG_CH=>NULL()
!$OMP THREADPRIVATE(XAVG_CH)
REAL, POINTER, DIMENSION(:)   :: XAVG_CE=>NULL()
!$OMP THREADPRIVATE(XAVG_CE)
REAL, POINTER, DIMENSION(:)   :: XAVG_RN=>NULL()
!$OMP THREADPRIVATE(XAVG_RN)
REAL, POINTER, DIMENSION(:)   :: XAVG_H=>NULL()
!$OMP THREADPRIVATE(XAVG_H)
REAL, POINTER, DIMENSION(:)   :: XAVG_LE=>NULL()
!$OMP THREADPRIVATE(XAVG_LE)
REAL, POINTER, DIMENSION(:)   :: XAVG_LEI=>NULL()
!$OMP THREADPRIVATE(XAVG_LEI)
REAL, POINTER, DIMENSION(:)   :: XAVG_GFLUX=>NULL()
!$OMP THREADPRIVATE(XAVG_GFLUX)
REAL, POINTER, DIMENSION(:)   :: XAVG_TS=>NULL()
!$OMP THREADPRIVATE(XAVG_TS)
REAL, POINTER, DIMENSION(:)   :: XAVG_T2M=>NULL()
!$OMP THREADPRIVATE(XAVG_T2M)
REAL, POINTER, DIMENSION(:)   :: XAVG_T2M_MIN=>NULL()
!$OMP THREADPRIVATE(XAVG_T2M_MIN)
REAL, POINTER, DIMENSION(:)   :: XAVG_T2M_MAX=>NULL()
!$OMP THREADPRIVATE(XAVG_T2M_MAX)
REAL, POINTER, DIMENSION(:)   :: XAVG_Q2M=>NULL()
!$OMP THREADPRIVATE(XAVG_Q2M)
REAL, POINTER, DIMENSION(:)   :: XAVG_HU2M=>NULL()
!$OMP THREADPRIVATE(XAVG_HU2M)
REAL, POINTER, DIMENSION(:)   :: XAVG_HU2M_MIN=>NULL()
!$OMP THREADPRIVATE(XAVG_HU2M_MIN)
REAL, POINTER, DIMENSION(:)   :: XAVG_HU2M_MAX=>NULL()
!$OMP THREADPRIVATE(XAVG_HU2M_MAX)
REAL, POINTER, DIMENSION(:)   :: XAVG_ZON10M=>NULL()
!$OMP THREADPRIVATE(XAVG_ZON10M)
REAL, POINTER, DIMENSION(:)   :: XAVG_MER10M=>NULL()
!$OMP THREADPRIVATE(XAVG_MER10M)
REAL, POINTER, DIMENSION(:)   :: XAVG_WIND10M=>NULL()
!$OMP THREADPRIVATE(XAVG_WIND10M)
REAL, POINTER, DIMENSION(:)   :: XAVG_WIND10M_MAX=>NULL()
!$OMP THREADPRIVATE(XAVG_WIND10M_MAX)
REAL, POINTER, DIMENSION(:)   :: XAVG_SFCO2=>NULL()
!$OMP THREADPRIVATE(XAVG_SFCO2)
REAL, POINTER, DIMENSION(:)   :: XAVG_T2M_MIN_ZS=>NULL()
!$OMP THREADPRIVATE(XAVG_T2M_MIN_ZS)
REAL, POINTER, DIMENSION(:)   :: XAVG_Q2M_MIN_ZS=>NULL()
!$OMP THREADPRIVATE(XAVG_Q2M_MIN_ZS)
REAL, POINTER, DIMENSION(:)   :: XAVG_HU2M_MIN_ZS=>NULL()
!$OMP THREADPRIVATE(XAVG_HU2M_MIN_ZS)
REAL, POINTER, DIMENSION(:)   :: XPS=>NULL()
!$OMP THREADPRIVATE(XPS)
REAL, POINTER, DIMENSION(:)   :: XRHOA=>NULL()
!$OMP THREADPRIVATE(XRHOA)
REAL, POINTER, DIMENSION(:)   :: XAVG_QS=>NULL()
!$OMP THREADPRIVATE(XAVG_QS)
REAL, POINTER, DIMENSION(:)   :: XAVG_Z0=>NULL()
!$OMP THREADPRIVATE(XAVG_Z0)
REAL, POINTER, DIMENSION(:)   :: XAVG_Z0H=>NULL()
!$OMP THREADPRIVATE(XAVG_Z0H)
REAL, POINTER, DIMENSION(:)   :: XAVG_SWD=>NULL()
!$OMP THREADPRIVATE(XAVG_SWD)
REAL, POINTER, DIMENSION(:)   :: XAVG_SWU=>NULL()
!$OMP THREADPRIVATE(XAVG_SWU)
REAL, POINTER, DIMENSION(:)   :: XAVG_LWD=>NULL()
!$OMP THREADPRIVATE(XAVG_LWD)
REAL, POINTER, DIMENSION(:)   :: XAVG_LWU=>NULL()
!$OMP THREADPRIVATE(XAVG_LWU)
REAL, POINTER, DIMENSION(:,:) :: XAVG_SWBD=>NULL()
!$OMP THREADPRIVATE(XAVG_SWBD)
REAL, POINTER, DIMENSION(:,:) :: XAVG_SWBU=>NULL()
!$OMP THREADPRIVATE(XAVG_SWBU)
REAL, POINTER, DIMENSION(:)   :: XAVG_FMU=>NULL()
!$OMP THREADPRIVATE(XAVG_FMU)
REAL, POINTER, DIMENSION(:)   :: XAVG_FMV=>NULL()
!$OMP THREADPRIVATE(XAVG_FMV)
REAL, POINTER, DIMENSION(:)   :: XSSO_FMU=>NULL()
!$OMP THREADPRIVATE(XSSO_FMU)
REAL, POINTER, DIMENSION(:)   :: XSSO_FMV=>NULL()
!$OMP THREADPRIVATE(XSSO_FMV)
REAL, POINTER, DIMENSION(:)   :: XDIAG_ZREF=>NULL()
!$OMP THREADPRIVATE(XDIAG_ZREF)
REAL, POINTER, DIMENSION(:)   :: XDIAG_UREF=>NULL()
!$OMP THREADPRIVATE(XDIAG_UREF)
REAL, POINTER, DIMENSION(:)   :: XDIAG_TRAD=>NULL()
!$OMP THREADPRIVATE(XDIAG_TRAD)
REAL, POINTER, DIMENSION(:)   :: XDIAG_EMIS=>NULL()
!$OMP THREADPRIVATE(XDIAG_EMIS)
REAL, POINTER, DIMENSION(:)   :: XAVG_RNC=>NULL()
!$OMP THREADPRIVATE(XAVG_RNC)
REAL, POINTER, DIMENSION(:)   :: XAVG_HC=>NULL()
!$OMP THREADPRIVATE(XAVG_HC)
REAL, POINTER, DIMENSION(:)   :: XAVG_LEC=>NULL()
!$OMP THREADPRIVATE(XAVG_LEC)
REAL, POINTER, DIMENSION(:)   :: XAVG_LEIC=>NULL()
!$OMP THREADPRIVATE(XAVG_LEIC)
REAL, POINTER, DIMENSION(:)   :: XAVG_GFLUXC=>NULL()
!$OMP THREADPRIVATE(XAVG_GFLUXC)
REAL, POINTER, DIMENSION(:)   :: XAVG_SWDC=>NULL()
!$OMP THREADPRIVATE(XAVG_SWDC)
REAL, POINTER, DIMENSION(:)   :: XAVG_SWUC=>NULL()
!$OMP THREADPRIVATE(XAVG_SWUC)
REAL, POINTER, DIMENSION(:)   :: XAVG_LWDC=>NULL()
!$OMP THREADPRIVATE(XAVG_LWDC)
REAL, POINTER, DIMENSION(:)   :: XAVG_LWUC=>NULL()
!$OMP THREADPRIVATE(XAVG_LWUC)
REAL, POINTER, DIMENSION(:)   :: XAVG_FMUC=>NULL()
!$OMP THREADPRIVATE(XAVG_FMUC)
REAL, POINTER, DIMENSION(:)   :: XAVG_FMVC=>NULL()
!$OMP THREADPRIVATE(XAVG_FMVC)
!
REAL, POINTER, DIMENSION(:)   :: XRW_RAIN=>NULL()
!$OMP THREADPRIVATE(XRW_RAIN)
REAL, POINTER, DIMENSION(:)   :: XRW_SNOW=>NULL()
!$OMP THREADPRIVATE(XRW_SNOW)

CONTAINS

SUBROUTINE DIAG_SURF_ATM_GOTO_MODEL(KFROM, KTO, LKFROM)
LOGICAL, INTENT(IN) :: LKFROM
INTEGER, INTENT(IN) :: KFROM, KTO
REAL(KIND=JPRB) :: ZHOOK_HANDLE
!
! Save current state for allocated arrays
IF (LKFROM) THEN
DIAG_SURF_ATM_MODEL(KFROM)%CSELECT=>CSELECT
DIAG_SURF_ATM_MODEL(KFROM)%XRI_TILE=>XRI_TILE
DIAG_SURF_ATM_MODEL(KFROM)%XCD_TILE=>XCD_TILE
DIAG_SURF_ATM_MODEL(KFROM)%XCH_TILE=>XCH_TILE
DIAG_SURF_ATM_MODEL(KFROM)%XCE_TILE=>XCE_TILE
DIAG_SURF_ATM_MODEL(KFROM)%XRN_TILE=>XRN_TILE
DIAG_SURF_ATM_MODEL(KFROM)%XH_TILE=>XH_TILE
DIAG_SURF_ATM_MODEL(KFROM)%XLE_TILE=>XLE_TILE
DIAG_SURF_ATM_MODEL(KFROM)%XLEI_TILE=>XLEI_TILE
DIAG_SURF_ATM_MODEL(KFROM)%XGFLUX_TILE=>XGFLUX_TILE
DIAG_SURF_ATM_MODEL(KFROM)%XTS_TILE=>XTS_TILE
DIAG_SURF_ATM_MODEL(KFROM)%XT2M_TILE=>XT2M_TILE
DIAG_SURF_ATM_MODEL(KFROM)%XT2M_MIN_TILE=>XT2M_MIN_TILE
DIAG_SURF_ATM_MODEL(KFROM)%XT2M_MAX_TILE=>XT2M_MAX_TILE
DIAG_SURF_ATM_MODEL(KFROM)%XQ2M_TILE=>XQ2M_TILE
DIAG_SURF_ATM_MODEL(KFROM)%XHU2M_TILE=>XHU2M_TILE
DIAG_SURF_ATM_MODEL(KFROM)%XHU2M_MIN_TILE=>XHU2M_MIN_TILE
DIAG_SURF_ATM_MODEL(KFROM)%XHU2M_MAX_TILE=>XHU2M_MAX_TILE
DIAG_SURF_ATM_MODEL(KFROM)%XZON10M_TILE=>XZON10M_TILE
DIAG_SURF_ATM_MODEL(KFROM)%XMER10M_TILE=>XMER10M_TILE
DIAG_SURF_ATM_MODEL(KFROM)%XWIND10M_TILE=>XWIND10M_TILE
DIAG_SURF_ATM_MODEL(KFROM)%XWIND10M_MAX_TILE=>XWIND10M_MAX_TILE
DIAG_SURF_ATM_MODEL(KFROM)%XQS_TILE=>XQS_TILE
DIAG_SURF_ATM_MODEL(KFROM)%XZ0_TILE=>XZ0_TILE
DIAG_SURF_ATM_MODEL(KFROM)%XZ0H_TILE=>XZ0H_TILE
DIAG_SURF_ATM_MODEL(KFROM)%XSWD_TILE=>XSWD_TILE
DIAG_SURF_ATM_MODEL(KFROM)%XSWU_TILE=>XSWU_TILE
DIAG_SURF_ATM_MODEL(KFROM)%XLWD_TILE=>XLWD_TILE
DIAG_SURF_ATM_MODEL(KFROM)%XLWU_TILE=>XLWU_TILE
DIAG_SURF_ATM_MODEL(KFROM)%XSWBD_TILE=>XSWBD_TILE
DIAG_SURF_ATM_MODEL(KFROM)%XSWBU_TILE=>XSWBU_TILE
DIAG_SURF_ATM_MODEL(KFROM)%XFMU_TILE=>XFMU_TILE
DIAG_SURF_ATM_MODEL(KFROM)%XFMV_TILE=>XFMV_TILE
DIAG_SURF_ATM_MODEL(KFROM)%XRNC_TILE=>XRNC_TILE
DIAG_SURF_ATM_MODEL(KFROM)%XHC_TILE=>XHC_TILE
DIAG_SURF_ATM_MODEL(KFROM)%XLEC_TILE=>XLEC_TILE
DIAG_SURF_ATM_MODEL(KFROM)%XLEIC_TILE=>XLEIC_TILE
DIAG_SURF_ATM_MODEL(KFROM)%XGFLUXC_TILE=>XGFLUXC_TILE
DIAG_SURF_ATM_MODEL(KFROM)%XSWDC_TILE=>XSWDC_TILE
DIAG_SURF_ATM_MODEL(KFROM)%XSWUC_TILE=>XSWUC_TILE
DIAG_SURF_ATM_MODEL(KFROM)%XLWDC_TILE=>XLWDC_TILE
DIAG_SURF_ATM_MODEL(KFROM)%XLWUC_TILE=>XLWUC_TILE
DIAG_SURF_ATM_MODEL(KFROM)%XFMUC_TILE=>XFMUC_TILE
DIAG_SURF_ATM_MODEL(KFROM)%XFMVC_TILE=>XFMVC_TILE
DIAG_SURF_ATM_MODEL(KFROM)%XAVG_RI=>XAVG_RI
DIAG_SURF_ATM_MODEL(KFROM)%XAVG_CD=>XAVG_CD
DIAG_SURF_ATM_MODEL(KFROM)%XAVG_CH=>XAVG_CH
DIAG_SURF_ATM_MODEL(KFROM)%XAVG_CE=>XAVG_CE
DIAG_SURF_ATM_MODEL(KFROM)%XAVG_RN=>XAVG_RN
DIAG_SURF_ATM_MODEL(KFROM)%XAVG_H=>XAVG_H
DIAG_SURF_ATM_MODEL(KFROM)%XAVG_LE=>XAVG_LE
DIAG_SURF_ATM_MODEL(KFROM)%XAVG_LEI=>XAVG_LEI
DIAG_SURF_ATM_MODEL(KFROM)%XAVG_GFLUX=>XAVG_GFLUX
DIAG_SURF_ATM_MODEL(KFROM)%XAVG_TS=>XAVG_TS
DIAG_SURF_ATM_MODEL(KFROM)%XAVG_T2M=>XAVG_T2M
DIAG_SURF_ATM_MODEL(KFROM)%XAVG_T2M_MIN=>XAVG_T2M_MIN
DIAG_SURF_ATM_MODEL(KFROM)%XAVG_T2M_MAX=>XAVG_T2M_MAX
DIAG_SURF_ATM_MODEL(KFROM)%XAVG_Q2M=>XAVG_Q2M
DIAG_SURF_ATM_MODEL(KFROM)%XAVG_HU2M=>XAVG_HU2M
DIAG_SURF_ATM_MODEL(KFROM)%XAVG_HU2M_MIN=>XAVG_HU2M_MIN
DIAG_SURF_ATM_MODEL(KFROM)%XAVG_HU2M_MAX=>XAVG_HU2M_MAX
DIAG_SURF_ATM_MODEL(KFROM)%XAVG_ZON10M=>XAVG_ZON10M
DIAG_SURF_ATM_MODEL(KFROM)%XAVG_MER10M=>XAVG_MER10M
DIAG_SURF_ATM_MODEL(KFROM)%XAVG_WIND10M=>XAVG_WIND10M
DIAG_SURF_ATM_MODEL(KFROM)%XAVG_WIND10M_MAX=>XAVG_WIND10M_MAX
DIAG_SURF_ATM_MODEL(KFROM)%XAVG_SFCO2=>XAVG_SFCO2
DIAG_SURF_ATM_MODEL(KFROM)%XAVG_T2M_MIN_ZS=>XAVG_T2M_MIN_ZS
DIAG_SURF_ATM_MODEL(KFROM)%XAVG_Q2M_MIN_ZS=>XAVG_Q2M_MIN_ZS
DIAG_SURF_ATM_MODEL(KFROM)%XAVG_HU2M_MIN_ZS=>XAVG_HU2M_MIN_ZS
DIAG_SURF_ATM_MODEL(KFROM)%XPS=>XPS
DIAG_SURF_ATM_MODEL(KFROM)%XRHOA=>XRHOA
DIAG_SURF_ATM_MODEL(KFROM)%XAVG_QS=>XAVG_QS
DIAG_SURF_ATM_MODEL(KFROM)%XAVG_Z0=>XAVG_Z0
DIAG_SURF_ATM_MODEL(KFROM)%XAVG_Z0H=>XAVG_Z0H
DIAG_SURF_ATM_MODEL(KFROM)%XAVG_SWD=>XAVG_SWD
DIAG_SURF_ATM_MODEL(KFROM)%XAVG_SWU=>XAVG_SWU
DIAG_SURF_ATM_MODEL(KFROM)%XAVG_LWD=>XAVG_LWD
DIAG_SURF_ATM_MODEL(KFROM)%XAVG_LWU=>XAVG_LWU
DIAG_SURF_ATM_MODEL(KFROM)%XAVG_SWBD=>XAVG_SWBD
DIAG_SURF_ATM_MODEL(KFROM)%XAVG_SWBU=>XAVG_SWBU
DIAG_SURF_ATM_MODEL(KFROM)%XAVG_FMU=>XAVG_FMU
DIAG_SURF_ATM_MODEL(KFROM)%XAVG_FMV=>XAVG_FMV
DIAG_SURF_ATM_MODEL(KFROM)%XSSO_FMU=>XSSO_FMU
DIAG_SURF_ATM_MODEL(KFROM)%XSSO_FMV=>XSSO_FMV
DIAG_SURF_ATM_MODEL(KFROM)%XDIAG_UREF=>XDIAG_UREF
DIAG_SURF_ATM_MODEL(KFROM)%XDIAG_ZREF=>XDIAG_ZREF
DIAG_SURF_ATM_MODEL(KFROM)%XDIAG_TRAD=>XDIAG_TRAD
DIAG_SURF_ATM_MODEL(KFROM)%XDIAG_EMIS=>XDIAG_EMIS
DIAG_SURF_ATM_MODEL(KFROM)%XAVG_RNC=>XAVG_RNC
DIAG_SURF_ATM_MODEL(KFROM)%XAVG_HC=>XAVG_HC
DIAG_SURF_ATM_MODEL(KFROM)%XAVG_LEC=>XAVG_LEC
DIAG_SURF_ATM_MODEL(KFROM)%XAVG_LEIC=>XAVG_LEIC
DIAG_SURF_ATM_MODEL(KFROM)%XAVG_GFLUXC=>XAVG_GFLUXC
DIAG_SURF_ATM_MODEL(KFROM)%XAVG_SWDC=>XAVG_SWDC
DIAG_SURF_ATM_MODEL(KFROM)%XAVG_SWUC=>XAVG_SWUC
DIAG_SURF_ATM_MODEL(KFROM)%XAVG_LWDC=>XAVG_LWDC
DIAG_SURF_ATM_MODEL(KFROM)%XAVG_LWUC=>XAVG_LWUC
DIAG_SURF_ATM_MODEL(KFROM)%XAVG_FMUC=>XAVG_FMUC
DIAG_SURF_ATM_MODEL(KFROM)%XAVG_FMVC=>XAVG_FMVC
!
DIAG_SURF_ATM_MODEL(KFROM)%XRW_RAIN=>XRW_RAIN
DIAG_SURF_ATM_MODEL(KFROM)%XRW_SNOW=>XRW_SNOW
ENDIF
!
! Current model is set to model KTO
IF (LHOOK) CALL DR_HOOK('MODD_DIAG_SURF_ATM_N:DIAG_SURF_ATM_GOTO_MODEL',0,ZHOOK_HANDLE)
XDIAG_TSTEP=>DIAG_SURF_ATM_MODEL(KTO)%XDIAG_TSTEP
N2M=>DIAG_SURF_ATM_MODEL(KTO)%N2M
L2M_MIN_ZS=>DIAG_SURF_ATM_MODEL(KTO)%L2M_MIN_ZS
LSURF_BUDGET=>DIAG_SURF_ATM_MODEL(KTO)%LSURF_BUDGET
LRAD_BUDGET=>DIAG_SURF_ATM_MODEL(KTO)%LRAD_BUDGET
LCOEF=>DIAG_SURF_ATM_MODEL(KTO)%LCOEF
LSURF_VARS=>DIAG_SURF_ATM_MODEL(KTO)%LSURF_VARS
LFRAC=>DIAG_SURF_ATM_MODEL(KTO)%LFRAC
LDIAG_GRID=>DIAG_SURF_ATM_MODEL(KTO)%LDIAG_GRID
LSURF_BUDGETC=>DIAG_SURF_ATM_MODEL(KTO)%LSURF_BUDGETC
LRESET_BUDGETC=>DIAG_SURF_ATM_MODEL(KTO)%LRESET_BUDGETC
LREAD_BUDGETC=>DIAG_SURF_ATM_MODEL(KTO)%LREAD_BUDGETC
LPROVAR_TO_DIAG=>DIAG_SURF_ATM_MODEL(KTO)%LPROVAR_TO_DIAG
LSELECT=>DIAG_SURF_ATM_MODEL(KTO)%LSELECT
CSELECT=>DIAG_SURF_ATM_MODEL(KTO)%CSELECT
TIME_BUDGETC=>DIAG_SURF_ATM_MODEL(KTO)%TIME_BUDGETC
XRI_TILE=>DIAG_SURF_ATM_MODEL(KTO)%XRI_TILE
XCD_TILE=>DIAG_SURF_ATM_MODEL(KTO)%XCD_TILE
XCH_TILE=>DIAG_SURF_ATM_MODEL(KTO)%XCH_TILE
XCE_TILE=>DIAG_SURF_ATM_MODEL(KTO)%XCE_TILE
XRN_TILE=>DIAG_SURF_ATM_MODEL(KTO)%XRN_TILE
XH_TILE=>DIAG_SURF_ATM_MODEL(KTO)%XH_TILE
XLE_TILE=>DIAG_SURF_ATM_MODEL(KTO)%XLE_TILE
XLEI_TILE=>DIAG_SURF_ATM_MODEL(KTO)%XLEI_TILE
XGFLUX_TILE=>DIAG_SURF_ATM_MODEL(KTO)%XGFLUX_TILE
XTS_TILE=>DIAG_SURF_ATM_MODEL(KTO)%XTS_TILE
XT2M_TILE=>DIAG_SURF_ATM_MODEL(KTO)%XT2M_TILE
XT2M_MIN_TILE=>DIAG_SURF_ATM_MODEL(KTO)%XT2M_MIN_TILE
XT2M_MAX_TILE=>DIAG_SURF_ATM_MODEL(KTO)%XT2M_MAX_TILE
XQ2M_TILE=>DIAG_SURF_ATM_MODEL(KTO)%XQ2M_TILE
XHU2M_TILE=>DIAG_SURF_ATM_MODEL(KTO)%XHU2M_TILE
XHU2M_MIN_TILE=>DIAG_SURF_ATM_MODEL(KTO)%XHU2M_MIN_TILE
XHU2M_MAX_TILE=>DIAG_SURF_ATM_MODEL(KTO)%XHU2M_MAX_TILE
XZON10M_TILE=>DIAG_SURF_ATM_MODEL(KTO)%XZON10M_TILE
XMER10M_TILE=>DIAG_SURF_ATM_MODEL(KTO)%XMER10M_TILE
XWIND10M_TILE=>DIAG_SURF_ATM_MODEL(KTO)%XWIND10M_TILE
XWIND10M_MAX_TILE=>DIAG_SURF_ATM_MODEL(KTO)%XWIND10M_MAX_TILE
XQS_TILE=>DIAG_SURF_ATM_MODEL(KTO)%XQS_TILE
XZ0_TILE=>DIAG_SURF_ATM_MODEL(KTO)%XZ0_TILE
XZ0H_TILE=>DIAG_SURF_ATM_MODEL(KTO)%XZ0H_TILE
XSWD_TILE=>DIAG_SURF_ATM_MODEL(KTO)%XSWD_TILE
XSWU_TILE=>DIAG_SURF_ATM_MODEL(KTO)%XSWU_TILE
XLWD_TILE=>DIAG_SURF_ATM_MODEL(KTO)%XLWD_TILE
XLWU_TILE=>DIAG_SURF_ATM_MODEL(KTO)%XLWU_TILE
XSWBD_TILE=>DIAG_SURF_ATM_MODEL(KTO)%XSWBD_TILE
XSWBU_TILE=>DIAG_SURF_ATM_MODEL(KTO)%XSWBU_TILE
XFMU_TILE=>DIAG_SURF_ATM_MODEL(KTO)%XFMU_TILE
XFMV_TILE=>DIAG_SURF_ATM_MODEL(KTO)%XFMV_TILE
XRNC_TILE=>DIAG_SURF_ATM_MODEL(KTO)%XRNC_TILE
XHC_TILE=>DIAG_SURF_ATM_MODEL(KTO)%XHC_TILE
XLEC_TILE=>DIAG_SURF_ATM_MODEL(KTO)%XLEC_TILE
XLEIC_TILE=>DIAG_SURF_ATM_MODEL(KTO)%XLEIC_TILE
XGFLUXC_TILE=>DIAG_SURF_ATM_MODEL(KTO)%XGFLUXC_TILE
XSWDC_TILE=>DIAG_SURF_ATM_MODEL(KTO)%XSWDC_TILE
XSWUC_TILE=>DIAG_SURF_ATM_MODEL(KTO)%XSWUC_TILE
XLWDC_TILE=>DIAG_SURF_ATM_MODEL(KTO)%XLWDC_TILE
XLWUC_TILE=>DIAG_SURF_ATM_MODEL(KTO)%XLWUC_TILE
XFMUC_TILE=>DIAG_SURF_ATM_MODEL(KTO)%XFMUC_TILE
XFMVC_TILE=>DIAG_SURF_ATM_MODEL(KTO)%XFMVC_TILE
XAVG_RI=>DIAG_SURF_ATM_MODEL(KTO)%XAVG_RI
XAVG_CD=>DIAG_SURF_ATM_MODEL(KTO)%XAVG_CD
XAVG_CH=>DIAG_SURF_ATM_MODEL(KTO)%XAVG_CH
XAVG_CE=>DIAG_SURF_ATM_MODEL(KTO)%XAVG_CE
XAVG_RN=>DIAG_SURF_ATM_MODEL(KTO)%XAVG_RN
XAVG_H=>DIAG_SURF_ATM_MODEL(KTO)%XAVG_H
XAVG_LE=>DIAG_SURF_ATM_MODEL(KTO)%XAVG_LE
XAVG_LEI=>DIAG_SURF_ATM_MODEL(KTO)%XAVG_LEI
XAVG_GFLUX=>DIAG_SURF_ATM_MODEL(KTO)%XAVG_GFLUX
XAVG_TS=>DIAG_SURF_ATM_MODEL(KTO)%XAVG_TS
XAVG_T2M=>DIAG_SURF_ATM_MODEL(KTO)%XAVG_T2M
XAVG_T2M_MIN=>DIAG_SURF_ATM_MODEL(KTO)%XAVG_T2M_MIN
XAVG_T2M_MAX=>DIAG_SURF_ATM_MODEL(KTO)%XAVG_T2M_MAX
XAVG_Q2M=>DIAG_SURF_ATM_MODEL(KTO)%XAVG_Q2M
XAVG_HU2M=>DIAG_SURF_ATM_MODEL(KTO)%XAVG_HU2M
XAVG_HU2M_MIN=>DIAG_SURF_ATM_MODEL(KTO)%XAVG_HU2M_MIN
XAVG_HU2M_MAX=>DIAG_SURF_ATM_MODEL(KTO)%XAVG_HU2M_MAX
XAVG_ZON10M=>DIAG_SURF_ATM_MODEL(KTO)%XAVG_ZON10M
XAVG_MER10M=>DIAG_SURF_ATM_MODEL(KTO)%XAVG_MER10M
XAVG_WIND10M=>DIAG_SURF_ATM_MODEL(KTO)%XAVG_WIND10M
XAVG_WIND10M_MAX=>DIAG_SURF_ATM_MODEL(KTO)%XAVG_WIND10M_MAX
XAVG_SFCO2=>DIAG_SURF_ATM_MODEL(KTO)%XAVG_SFCO2
XAVG_T2M_MIN_ZS=>DIAG_SURF_ATM_MODEL(KTO)%XAVG_T2M_MIN_ZS
XAVG_Q2M_MIN_ZS=>DIAG_SURF_ATM_MODEL(KTO)%XAVG_Q2M_MIN_ZS
XAVG_HU2M_MIN_ZS=>DIAG_SURF_ATM_MODEL(KTO)%XAVG_HU2M_MIN_ZS
XPS=>DIAG_SURF_ATM_MODEL(KTO)%XPS
XRHOA=>DIAG_SURF_ATM_MODEL(KTO)%XRHOA
XAVG_QS=>DIAG_SURF_ATM_MODEL(KTO)%XAVG_QS
XAVG_Z0=>DIAG_SURF_ATM_MODEL(KTO)%XAVG_Z0
XAVG_Z0H=>DIAG_SURF_ATM_MODEL(KTO)%XAVG_Z0H
XAVG_SWD=>DIAG_SURF_ATM_MODEL(KTO)%XAVG_SWD
XAVG_SWU=>DIAG_SURF_ATM_MODEL(KTO)%XAVG_SWU
XAVG_LWD=>DIAG_SURF_ATM_MODEL(KTO)%XAVG_LWD
XAVG_LWU=>DIAG_SURF_ATM_MODEL(KTO)%XAVG_LWU
XAVG_SWBD=>DIAG_SURF_ATM_MODEL(KTO)%XAVG_SWBD
XAVG_SWBU=>DIAG_SURF_ATM_MODEL(KTO)%XAVG_SWBU
XAVG_FMU=>DIAG_SURF_ATM_MODEL(KTO)%XAVG_FMU
XAVG_FMV=>DIAG_SURF_ATM_MODEL(KTO)%XAVG_FMV
XSSO_FMU=>DIAG_SURF_ATM_MODEL(KTO)%XSSO_FMU
XSSO_FMV=>DIAG_SURF_ATM_MODEL(KTO)%XSSO_FMV
XDIAG_UREF=>DIAG_SURF_ATM_MODEL(KTO)%XDIAG_UREF
XDIAG_ZREF=>DIAG_SURF_ATM_MODEL(KTO)%XDIAG_ZREF
XDIAG_TRAD=>DIAG_SURF_ATM_MODEL(KTO)%XDIAG_TRAD
XDIAG_EMIS=>DIAG_SURF_ATM_MODEL(KTO)%XDIAG_EMIS
XAVG_RNC=>DIAG_SURF_ATM_MODEL(KTO)%XAVG_RNC
XAVG_HC=>DIAG_SURF_ATM_MODEL(KTO)%XAVG_HC
XAVG_LEC=>DIAG_SURF_ATM_MODEL(KTO)%XAVG_LEC
XAVG_LEIC=>DIAG_SURF_ATM_MODEL(KTO)%XAVG_LEIC
XAVG_GFLUXC=>DIAG_SURF_ATM_MODEL(KTO)%XAVG_GFLUXC
XAVG_SWDC=>DIAG_SURF_ATM_MODEL(KTO)%XAVG_SWDC
XAVG_SWUC=>DIAG_SURF_ATM_MODEL(KTO)%XAVG_SWUC
XAVG_LWDC=>DIAG_SURF_ATM_MODEL(KTO)%XAVG_LWDC
XAVG_LWUC=>DIAG_SURF_ATM_MODEL(KTO)%XAVG_LWUC
XAVG_FMUC=>DIAG_SURF_ATM_MODEL(KTO)%XAVG_FMUC
XAVG_FMVC=>DIAG_SURF_ATM_MODEL(KTO)%XAVG_FMVC
!
XRW_RAIN=>DIAG_SURF_ATM_MODEL(KTO)%XRW_RAIN
XRW_SNOW=>DIAG_SURF_ATM_MODEL(KTO)%XRW_SNOW
IF (LHOOK) CALL DR_HOOK('MODD_DIAG_SURF_ATM_N:DIAG_SURF_ATM_GOTO_MODEL',1,ZHOOK_HANDLE)
!
END SUBROUTINE DIAG_SURF_ATM_GOTO_MODEL

SUBROUTINE DIAG_SURF_ATM_ALLOC(KMODEL)
INTEGER, INTENT(IN) :: KMODEL
INTEGER :: J
REAL(KIND=JPRB) :: ZHOOK_HANDLE
IF (LHOOK) CALL DR_HOOK("MODD_DIAG_SURF_ATM_N:DIAG_SURF_ATM_ALLOC",0,ZHOOK_HANDLE)
ALLOCATE(DIAG_SURF_ATM_MODEL(KMODEL))
DO J=1,KMODEL
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XRI_TILE)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XCD_TILE)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XCH_TILE)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XCE_TILE)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XRN_TILE)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XH_TILE)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XLE_TILE)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XLEI_TILE)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XGFLUX_TILE)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XTS_TILE)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XT2M_TILE)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XT2M_MIN_TILE)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XT2M_MAX_TILE)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XQ2M_TILE)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XHU2M_TILE)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XHU2M_MIN_TILE)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XHU2M_MAX_TILE)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XZON10M_TILE)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XMER10M_TILE)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XWIND10M_TILE)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XWIND10M_MAX_TILE)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XQS_TILE)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XZ0_TILE)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XZ0H_TILE)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XSWD_TILE)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XSWU_TILE)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XLWD_TILE)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XLWU_TILE)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XSWBD_TILE)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XSWBU_TILE)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XFMU_TILE)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XFMV_TILE)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XRNC_TILE)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XHC_TILE)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XLEC_TILE)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XLEIC_TILE)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XGFLUXC_TILE)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XSWDC_TILE)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XSWUC_TILE)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XLWDC_TILE)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XLWUC_TILE)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XFMUC_TILE)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XFMVC_TILE)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XAVG_RI)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XAVG_CD)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XAVG_CH)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XAVG_CE)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XAVG_RN)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XAVG_H)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XAVG_LE)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XAVG_LEI)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XAVG_GFLUX)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XAVG_TS)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XAVG_T2M)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XAVG_Q2M)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XAVG_HU2M)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XAVG_ZON10M)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XAVG_MER10M)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XAVG_SFCO2)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XAVG_T2M_MIN_ZS)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XAVG_Q2M_MIN_ZS)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XAVG_HU2M_MIN_ZS)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XPS)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XRHOA)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XAVG_QS)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XAVG_Z0)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XAVG_Z0H)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XAVG_SWD)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XAVG_SWU)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XAVG_LWD)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XAVG_LWU)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XAVG_SWBD)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XAVG_SWBU)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XAVG_FMU)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XAVG_FMV)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XSSO_FMU)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XSSO_FMV)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XDIAG_UREF)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XDIAG_ZREF)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XDIAG_TRAD)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XDIAG_EMIS)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XAVG_T2M_MIN)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XAVG_T2M_MAX)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XAVG_HU2M_MIN)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XAVG_HU2M_MAX)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XAVG_WIND10M)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XAVG_WIND10M_MAX)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XAVG_RNC)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XAVG_HC)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XAVG_LEC)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XAVG_LEIC)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XAVG_GFLUXC)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XAVG_SWDC)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XAVG_SWUC)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XAVG_LWDC)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XAVG_LWUC)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XAVG_FMUC)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XAVG_FMVC)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XRW_RAIN)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%XRW_SNOW)
  NULLIFY(DIAG_SURF_ATM_MODEL(J)%CSELECT)
ENDDO
DIAG_SURF_ATM_MODEL(:)%XDIAG_TSTEP=0.
DIAG_SURF_ATM_MODEL(:)%N2M=0
DIAG_SURF_ATM_MODEL(:)%L2M_MIN_ZS=.FALSE.
DIAG_SURF_ATM_MODEL(:)%LSURF_BUDGET=.FALSE.
DIAG_SURF_ATM_MODEL(:)%LRAD_BUDGET=.FALSE.
DIAG_SURF_ATM_MODEL(:)%LCOEF=.FALSE.
DIAG_SURF_ATM_MODEL(:)%LSURF_VARS=.FALSE.
DIAG_SURF_ATM_MODEL(:)%LFRAC=.FALSE.
DIAG_SURF_ATM_MODEL(:)%LDIAG_GRID=.FALSE.
DIAG_SURF_ATM_MODEL(:)%LSURF_BUDGETC=.FALSE.
DIAG_SURF_ATM_MODEL(:)%LRESET_BUDGETC=.FALSE.
DIAG_SURF_ATM_MODEL(:)%LREAD_BUDGETC=.FALSE.
DIAG_SURF_ATM_MODEL(:)%LPROVAR_TO_DIAG=.FALSE.
DIAG_SURF_ATM_MODEL(:)%LSELECT=.FALSE.
IF (LHOOK) CALL DR_HOOK("MODD_DIAG_SURF_ATM_N:DIAG_SURF_ATM_ALLOC",1,ZHOOK_HANDLE)
END SUBROUTINE DIAG_SURF_ATM_ALLOC

SUBROUTINE DIAG_SURF_ATM_DEALLO
REAL(KIND=JPRB) :: ZHOOK_HANDLE
IF (LHOOK) CALL DR_HOOK("MODD_DIAG_SURF_ATM_N:DIAG_SURF_ATM_DEALLO",0,ZHOOK_HANDLE)
IF (ALLOCATED(DIAG_SURF_ATM_MODEL)) DEALLOCATE(DIAG_SURF_ATM_MODEL)
IF (LHOOK) CALL DR_HOOK("MODD_DIAG_SURF_ATM_N:DIAG_SURF_ATM_DEALLO",1,ZHOOK_HANDLE)
END SUBROUTINE DIAG_SURF_ATM_DEALLO

END MODULE MODD_DIAG_SURF_ATM_n
